@@ -1,7 +1,7 @@
 package DateTime::Format::ISO8601::Format;
 
-our $DATE = '2018-06-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-06-24'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +30,7 @@ sub new {
     bless $self, $class;
 }
 
-sub _format_date_or_time_datetime {
+sub _format_date_or_time_or_datetime {
     my ($self, $which, $dt) = @_;
 
     if ($self->{time_zone}) {
@@ -84,21 +84,21 @@ sub _format_date_or_time_datetime {
 
 sub format_date {
     my ($self, $dt) = @_;
-    $self->_format_date_or_time_datetime('date', $dt);
+    $self->_format_date_or_time_or_datetime('date', $dt);
 }
 
 sub format_time {
     my ($self, $dt) = @_;
-    $self->_format_date_or_time_datetime('time', $dt);
+    $self->_format_date_or_time_or_datetime('time', $dt);
 }
 
 sub format_datetime {
     my ($self, $dt) = @_;
-    $self->_format_date_or_time_datetime('datetime', $dt);
+    $self->_format_date_or_time_or_datetime('datetime', $dt);
 }
 
 1;
-# ABSTRACT: Format DateTime as ISO8601 date/time string
+# ABSTRACT: Format DateTime object as ISO8601 date/time string
 
 __END__
 
@@ -108,11 +108,11 @@ __END__
 
 =head1 NAME
 
-DateTime::Format::ISO8601::Format - Format DateTime as ISO8601 date/time string
+DateTime::Format::ISO8601::Format - Format DateTime object as ISO8601 date/time string
 
 =head1 VERSION
 
-This document describes version 0.002 of DateTime::Format::ISO8601::Format (from Perl distribution DateTime-Format-ISO8601-Format), released on 2018-06-23.
+This document describes version 0.003 of DateTime::Format::ISO8601::Format (from Perl distribution DateTime-Format-ISO8601-Format), released on 2018-06-24.
 
 =head1 SYNOPSIS
 
